@@ -6,6 +6,7 @@ from functools import partial
 import webbrowser
 import shutil
 import os
+from subprocess import Popen
 
 from PyQt5.QtGui import QIcon, QCursor
 from PyQt5.QtCore import pyqtSignal, QThread, QTimer
@@ -57,6 +58,9 @@ class VenvTable(QTableView):
         self.save_icon = QIcon(
             self.style().standardIcon(QStyle.SP_DialogSaveButton)
         )
+        self.folder_icon = QIcon(
+            self.style().standardIcon(QStyle.SP_DirOpenIcon)
+        )
 
         self.progress_bar = ProgBarDialog()
         self.console = ConsoleDialog()
@@ -92,6 +96,11 @@ class VenvTable(QTableView):
             icon=QIcon.fromTheme("software-install")
         )
 
+
+        #]===================================================================[#
+        #] ACTIONS [#========================================================[#
+        #]===================================================================[#
+
         upgrade_pip_action = QAction(
             QIcon.fromTheme("system-software-update"),
             "&Upgrade Pip to latest",
@@ -182,6 +191,16 @@ class VenvTable(QTableView):
             lambda: self.pipdeptree_output(event, style=3)
         )
 
+        open_venv_dir_action = QAction(
+            self.folder_icon,
+            "&Open containing folder",
+            self,
+            statusTip="Open the folder containing the virtual environment"
+        )
+        open_venv_dir_action.triggered.connect(
+            lambda: self.open_venv_dir(event)
+        )
+
         delete_venv_action = QAction(
             self.delete_icon,
             "&Delete environment",
@@ -192,6 +211,11 @@ class VenvTable(QTableView):
             lambda: self.delete_venv(event)
         )
 
+
+        #]===================================================================[#
+        #] ADD ACTIONS [#====================================================[#
+        #]===================================================================[#
+
         context_menu.addAction(upgrade_pip_action)
 
         # install sub menu
@@ -212,6 +236,7 @@ class VenvTable(QTableView):
         details_sub_menu.addAction(freeze_action)
         details_sub_menu.addAction(pipdeptree_action)
 
+        context_menu.addAction(open_venv_dir_action)
         context_menu.addAction(delete_venv_action)
 
         # pop up only if clicking on a row
@@ -415,9 +440,14 @@ class VenvTable(QTableView):
         """
         active_dir = get_active_dir_str()
         venv = self.get_selected_item()
+        venv_dir = os.path.join(active_dir, venv)
 
         if self.has_pip(active_dir, venv):
-            save_file = QFileDialog.getSaveFileName(self, "Save requirements")
+            save_file = QFileDialog.getSaveFileName(
+                self,
+                "Save requirements",
+                directory=f"{venv_dir}/requirements.txt"
+            )
             save_path = save_file[0]
 
             if save_path != "":
@@ -499,6 +529,18 @@ class VenvTable(QTableView):
                     self.list_modules(event, style)
 
 
+    def open_venv_dir(self, event):
+        """
+        Open the selected venv directory.
+        """
+        active_dir = get_active_dir_str()
+        venv = self.get_selected_item()
+        venv_dir = os.path.join(active_dir, venv)
+
+        if os.path.isdir(venv_dir):
+            Popen(["xdg-open", venv_dir])
+
+
     def delete_venv(self, event):
         """
         Delete the selected virtual environment by clicking
