@@ -43,7 +43,6 @@ from manage_pip import PipManager
 from tables import ResultsTable
 from get_data import (
     get_module_infos,
-    get_active_dir_str,
     get_python_installs,
     get_python_version
 )
@@ -74,7 +73,7 @@ class VenvWizard(QWizard):
         self.setWindowTitle("Venv Wizard")
         self.resize(680, 510)
         self.center()
-        self.setWindowIcon(QIcon(":/img/python.png"))
+        self.setWindowIcon(QIcon(":/img/profile.png"))
 
         self.setStyleSheet(
             """
@@ -647,12 +646,6 @@ class InstallModules(QWizardPage):
             # open the console when recieving signal from manager
             self.manager.started.connect(self.console.exec_)
 
-            #]===============================================================[#
-            # TODO: provide some options here:
-            #       * let the user decide whether to install packages with
-            #         the "--upgrade" flag or not
-            #       * let user specify a particular version to install
-            #]===============================================================[#
             # start installing the selected module
             print(f"[PROCESS]: Installing module '{self.pkg}'...")
             self.manager.run_pip(cmds[0], [opts[0], self.pkg])
@@ -684,8 +677,12 @@ class InstallModules(QWizardPage):
         )
 
         if msg_box_question == QMessageBox.Yes:
-            active_dir = get_active_dir_str()
-            save_file = QFileDialog.getSaveFileName(self, "Save requirements")
+            venv_dir = os.path.join(self.venv_location, self.venv_name)
+            save_file = QFileDialog.getSaveFileName(
+                self,
+                "Save requirements",
+                directory=f"{venv_dir}/requirements.txt"
+            )
             save_path = save_file[0]
 
             if save_path != "":
@@ -780,13 +777,17 @@ class FinalPage(QWizardPage):
         self.wizard().refresh.emit()
 
 
-
-if __name__ == "__main__":
-
+def main():
     app = QApplication(sys.argv)
     os.system("clear")
 
     wizard = VenvWizard()
+    wizard.basic_settings.pop_combo_box()
     wizard.show()
 
     sys.exit(app.exec_())
+
+
+
+if __name__ == "__main__":
+    main()
